@@ -38,7 +38,7 @@
  *
  * Since: 17.0.0
  */
-#define GPARQUET_VERSION_MAJOR (20)
+#define GPARQUET_VERSION_MAJOR (21)
 
 /**
  * GPARQUET_VERSION_MINOR:
@@ -110,6 +110,15 @@
 #  define GPARQUET_UNAVAILABLE(major, minor) G_UNAVAILABLE(major, minor)
 #endif
 
+/**
+ * GPARQUET_VERSION_21_0:
+ *
+ * You can use this macro value for compile time API version check.
+ *
+ * Since: 21.0.0
+ */
+#define GPARQUET_VERSION_21_0 G_ENCODE_VERSION(21, 0)
+
 /**
  * GPARQUET_VERSION_20_0:
  *
@@ -422,6 +431,20 @@
 
 #define GPARQUET_AVAILABLE_IN_ALL GPARQUET_EXTERN
 
+#if GPARQUET_VERSION_MIN_REQUIRED >= GPARQUET_VERSION_21_0
+#  define GPARQUET_DEPRECATED_IN_21_0               GPARQUET_DEPRECATED
+#  define GPARQUET_DEPRECATED_IN_21_0_FOR(function) GPARQUET_DEPRECATED_FOR(function)
+#else
+#  define GPARQUET_DEPRECATED_IN_21_0
+#  define GPARQUET_DEPRECATED_IN_21_0_FOR(function)
+#endif
+
+#if GPARQUET_VERSION_MAX_ALLOWED < GPARQUET_VERSION_21_0
+#  define GPARQUET_AVAILABLE_IN_21_0 GPARQUET_EXTERN GPARQUET_UNAVAILABLE(21, 0)
+#else
+#  define GPARQUET_AVAILABLE_IN_21_0 GPARQUET_EXTERN
+#endif
+
 #if GPARQUET_VERSION_MIN_REQUIRED >= GPARQUET_VERSION_20_0
 #  define GPARQUET_DEPRECATED_IN_20_0               GPARQUET_DEPRECATED
 #  define GPARQUET_DEPRECATED_IN_20_0_FOR(function) GPARQUET_DEPRECATED_FOR(function)
